@@ -1,25 +1,21 @@
 #' UVI(Ultra-violet Index)
 #'
 #' This functions calls upon the UVI API from data.gov.sg
-#' and returns the UVI value for the given data-time.
-#' This data provided by the API is updated hourly.
-#'
-#' Note that there is only information on the UVI between 0700 and 1900.
-#' Entering a date-time outside of the range would return the UVI of the
-#' closest date time instead.
-#'
+#' and returns a data frame of the different measures of the UVI across
+#' Singapore and returns the closest UVI value presently and for the past
+#' few hours. This data provided by the API is updated hourly.
 #'
 #' @param date_time Defaults to current (SGD) time. Format: YYYY-MM-DDTHH:MM:SS
 #'
 #' @keywords UVI
 #'
-#' @return A dataframe containing the UVI for the given date-time
+#' @return A dataframe containing the current and past hourly UVI
 #'
 #' @export
 #' @examples
 #' uvi()
-#' uvi(date_time = "2018-10-10T15:00:00")
-#' uvi(date_time = "2019-04-01T09:00:00")
+#' uvi(date = "2022-09-03T16:45:23")
+#' uvi(date = "2021-12-06T11:01:55")
 
 uvi = function(date_time = "") {
 
@@ -32,11 +28,14 @@ uvi = function(date_time = "") {
   # Error check
   content.output = parse_api_output(output)
 
+  if (length(content.output$items) == 0) {
+    stop("No data returned from API.")
+  }
+
   # Extracting Data Frame
   message("Closest timestamp: ", content.output$items[[1]]$timestamp)
 
-  uvi = as.data.frame(content.output$items[[1]]$index[[1]])
-  uvi = uvi[ , c(2, 1)]
+  uvi = as.data.frame(dplyr::bind_rows(content.output$items[[1]]$index))
 
   return(uvi)
 
