@@ -1,4 +1,4 @@
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
@@ -10,10 +10,10 @@ library(dplyr)
 carpark_availability(date = "2019-06-05T10:10:10") %>% head()
 
 ## -----------------------------------------------------------------------------
-# pm25(date_time = "2018-01-04T09:16:17")
+pm25(date_time = "2018-01-04T09:16:17")
 
 ## -----------------------------------------------------------------------------
-# pm25_summary(date = "2018-01-04") %>% head()
+pm25_summary(date = "2018-01-04") %>% head()
 
 ## -----------------------------------------------------------------------------
 psi(date = "2019-11-08T17:30:00") %>% head()
